import type React from 'react';
import { FrameworkConfigurator } from '@equinor/fusion-framework';
import type { AnyModule, ModulesInstanceType } from '@equinor/fusion-framework-module';
/**
 * Create a framework provider for react.
 *
 * This function is for providers of framework, like a portal.
 *
 * @param configurator - callback for configuring modules
 * @example
 * ```tsx
 * const config: FrameworkConfigurator = (config) => {}
 * const Portal = () => {
 *   const Framework = createFrameworkProvider(config);
 *   return (
 *      <Suspense fallback={<span>loading...</span>}>
 *          <Framework>{children}</Framework>
 *      </Suspense>
 *   );
 * };
 * ```
 */
export declare const createFrameworkProvider: <TModules extends Array<AnyModule> = [], TRef extends ModulesInstanceType<[AnyModule]> = any>(cb: (configurator: FrameworkConfigurator<TModules>, ref?: TRef) => void | Promise<void>, ref?: TRef) => React.LazyExoticComponent<React.FunctionComponent<React.PropsWithChildren<unknown>>>;
